==> xcsoar-6.5.4.tar.bz2: xcsoar-6.5.4/src/Dialogs/TextEntry.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef DIALOGS_TEXT_ENTRY_HPP
#define DIALOGS_TEXT_ENTRY_HPP

#include "Util/StaticString.hpp"

#include <functional>

#include <tchar.h>

typedef std::function<const TCHAR *(const TCHAR *)> AllowedCharacters;

bool
dlgTextEntryShowModal(TCHAR *text, size_t size,
                      const TCHAR *caption=nullptr,
                      AllowedCharacters ac=AllowedCharacters());

template<size_t N>
static inline bool
TextEntryDialog(StaticString<N> &text,
                const TCHAR *caption=NULL,
                AllowedCharacters accb=AllowedCharacters())
{
  return dlgTextEntryShowModal(text.buffer(), text.MAX_SIZE,
                               caption, accb);
}

bool
dlgTextEntryKeyboardShowModal(TCHAR *text, size_t size,
                              const TCHAR* caption=nullptr,
                              AllowedCharacters ac=AllowedCharacters());

#endif

==> xcsoar-6.7.1.tar.bz2: xcsoar-6.7.1/src/Dialogs/TextEntry.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef DIALOGS_TEXT_ENTRY_HPP
#define DIALOGS_TEXT_ENTRY_HPP

#include "Util/StaticString.hpp"

#include <functional>

#include <tchar.h>

typedef std::function<const TCHAR *(const TCHAR *)> AllowedCharacters;

bool
TextEntryDialog(TCHAR *text, size_t size,
                const TCHAR *caption=nullptr,
                AllowedCharacters ac=AllowedCharacters());

template<size_t N>
static inline bool
TextEntryDialog(StaticString<N> &text,
                const TCHAR *caption=NULL,
                AllowedCharacters accb=AllowedCharacters())
{
  return TextEntryDialog(text.buffer(), text.MAX_SIZE,
                         caption, accb);
}

void
KnobTextEntry(TCHAR *text, size_t width,
              const TCHAR *caption);

bool
TouchTextEntry(TCHAR *text, size_t size,
               const TCHAR *caption=nullptr,
               AllowedCharacters ac=AllowedCharacters());

#endif
